# Copyright 2019 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can
# found in the LICENSE file.

from recipe_engine.post_process import StepCanceled

from RECIPE_MODULES.fuchsia.artifacts.api import TRANSIENT_ERROR_RETCODE

DEPS = [
    "fuchsia/artifacts",
    "fuchsia/build",
    "fuchsia/buildbucket_util",
    "fuchsia/checkout",
    "recipe_engine/buildbucket",
    "recipe_engine/json",
    "recipe_engine/path",
]

UPLOAD_TIMEOUT = 30 * 60


def RunSteps(api):
    checkout = api.checkout.fuchsia_with_options(
        manifest="minimal",
        remote="https://fuchsia.googlesource.com/manifest",
    )
    api.build.with_options(
        checkout=checkout,
        fint_params_path="fint_params/builder.textproto",
    )

    upload_manifest = api.json.input(
        [
            {"source": "a.txt", "destination": "a.txt"},
            {"source": "blob", "destination": "blobs/1/blob"},
        ]
    )
    api.artifacts.verify_blobs(
        "verify blobs",
        upload_manifest,
    )
    api.artifacts.gcs_bucket = "fuchsia-artifacts"
    api.artifacts.namespace = api.buildbucket_util.id
    api.artifacts.upload(
        "upload artifacts",
        upload_manifest,
        sign_artifacts=True,
        timeout_secs=UPLOAD_TIMEOUT,
    )
    api.artifacts.download("download artifact", "src", api.path.start_dir / "dest")
    api.artifacts.debug_symbol_url()
    api.artifacts.package_repo_url()
    api.artifacts.package_repo_url(host="127.0.0.1")
    api.artifacts.package_blob_url()
    api.artifacts.package_blob_url(host="127.0.0.1")
    api.artifacts.image_url()
    api.artifacts.image_url(host="127.0.0.1")
    api.artifacts.assembly_manifest_url()


def GenTests(api):
    yield api.test("basic") + api.buildbucket.try_build()
    yield (
        api.test("transient_failure", status="INFRA_FAILURE")
        + api.step_data("upload artifacts", retcode=TRANSIENT_ERROR_RETCODE)
    )
    yield (
        api.test("non_transient_failure", status="FAILURE")
        + api.step_data("upload artifacts", retcode=1)
    )
    yield (
        api.test("build_cancelled", status="INFRA_FAILURE")
        + api.step_data("upload artifacts", cancel=True)
        + api.post_process(StepCanceled, "upload artifacts")
    )
    yield (
        api.test("timeout", status="INFRA_FAILURE")
        + api.step_data("upload artifacts", times_out_after=UPLOAD_TIMEOUT + 1)
    )
