# -*- coding: utf-8 -*-
# Copyright 2019 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from PB.go.chromium.org.luci.buildbucket.proto import (
    builder_common as builder_common_pb2,
    common as common_pb2,
)

DEPS = [
    "fuchsia/buildbucket_util",
    "recipe_engine/buildbucket",
    "recipe_engine/properties",
    "recipe_engine/step",
]


def RunSteps(api):
    builds = api.buildbucket.collect_builds(
        build_ids=[
            123456789012345678,
            987654321098765432,
            112233445566778899,
            199887766554433221,
        ]
    )
    _, build = builds.popitem()
    api.buildbucket_util.last_build(
        status=common_pb2.FAILURE,
    )

    api.buildbucket_util.build_status(api.step.StepFailure("step failed"))

    api.buildbucket_util.build_status(api.step.InfraFailure("infra step failed"))

    api.buildbucket_util.build_status(Exception("recipe crash"))

    api.buildbucket_util.full_builder_name(
        builder_common_pb2.BuilderID(
            project=build.builder.project,
            bucket=f"{build.builder.bucket}.shadow",
            builder=build.builder.builder,
        ),
    )

    api.buildbucket_util.full_builder_name(
        builder_common_pb2.BuilderID(
            project=build.builder.project,
            bucket=f"{build.builder.bucket}.shadow",
            builder=build.builder.builder,
        ),
        remove_shadow=True,
    )

    # Truncation should happen here due to overlarge raw text and small max line
    # length.
    api.buildbucket_util.summary_message(
        "INFO: useful information\n" * 1000,
        "(message truncated)",
        max_line_length=5,
    )
    # No truncation should happen here.
    api.buildbucket_util.summary_message(
        "INFO: useful information\n" * 10,
        "(message truncated)",
    )

    # Truncation should happen here, but the split must not be in the middle of
    # a unicode char's bytes or else the string will no longer be valid utf-8
    # and passing it into a Build proto's summary_markdown field will fail.
    char = "→"
    char_byte_count = len(char.encode("utf-8"))
    original_summary = char * 10
    truncation_message = "(message truncated)"
    truncated_summary = api.buildbucket_util.summary_message(
        original_summary, truncation_message, max_line_length=(5 * char_byte_count) - 1
    )
    assert (
        truncated_summary == f"```\n{char * 3}...\n```\n\n{truncation_message}"
    ), truncated_summary
    api.step.empty("summary", step_text=truncated_summary)

    # pylint: disable=pointless-statement
    api.buildbucket_util.triggering_branch
    api.buildbucket_util.is_dev_environment
    api.buildbucket_util.is_dev_or_try
    api.buildbucket_util.is_shadowed
    api.buildbucket_util.is_tryjob
    api.buildbucket_util.id
    api.buildbucket_util.build_url
    api.buildbucket_util.bucket
    # pylint: enable=pointless-statement


def GenTests(api):
    yield (
        api.buildbucket_util.test("basic_tryjob", tryjob=True)
        + api.buildbucket.simulated_search_results([api.buildbucket.ci_build_message()])
        + api.buildbucket_util.tryjob_branch("some-branch")
    )

    yield (
        api.buildbucket_util.test("led_job")
        + api.properties(
            **{"$recipe_engine/led": {"led_run_id": "led/user_example.com/abc123"}}
        )
    )

    yield (
        api.buildbucket_util.test("led_real_build")
        + api.properties(**{"$recipe_engine/led": {"shadowed_bucket": "shade"}})
    )

    yield api.test("empty_build_input")
