# Copyright 2023 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Test API for builder_status."""

from PB.go.chromium.org.luci.buildbucket.proto import build as build_pb2
from PB.go.chromium.org.luci.buildbucket.proto import common as common_pb2
from PB.go.chromium.org.luci.buildbucket.proto import project_config as bb_pb2
from recipe_engine import recipe_test_api


class BuilderStatusTestApi(recipe_test_api.RecipeTestApi):
    """Test API for builder_status."""

    def buildbucket_config(self, *, project="fuchsia", nesting=None, **kwargs):
        if not kwargs:
            kwargs = {
                "ci": ("excluded", "test"),
                "try": ("excluded", "test"),
            }

        cfg = bb_pb2.BuildbucketCfg()
        for bucket_name, builder_names in kwargs.items():
            bucket = bb_pb2.Bucket(name=bucket_name)
            for builder_name in builder_names:
                builder = bb_pb2.BuilderConfig(name=builder_name)
                bucket.swarming.builders.append(builder)
            cfg.buckets.append(bucket)

        return self.m.luci_config.mock_config(
            project=project,
            config_name="cr-buildbucket.cfg",
            nesting=nesting,
            data=cfg,
        )

    def scheduled(self):
        return build_pb2.Build(status=common_pb2.SCHEDULED)

    def running(self):
        return build_pb2.Build(status=common_pb2.STARTED)

    def failure(self):
        return build_pb2.Build(status=common_pb2.FAILURE)

    def infra_failure(self):
        return build_pb2.Build(status=common_pb2.INFRA_FAILURE)

    def passed(self):
        return build_pb2.Build(status=common_pb2.SUCCESS)
