#!/usr/bin/env python3
# Copyright 2022 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Writes an output file after substituting ${} placeholders in the input file."""
import os
import argparse
import string


def _eval_gce_meta_placeholders():
    """Get the address at which GCE metadata server is running."""
    return {"luci_gce_meta": os.environ["GCE_METADATA_HOST"]}


def main():
    parser = argparse.ArgumentParser(
        description="Writes an output file after substituting ${} placeholders in the input file.",
    )
    parser.add_argument("-i", "--input", required=True, help="Path to innput file")
    parser.add_argument("-o", "--output", required=True, help="Path to output file")
    args = parser.parse_args()

    placeholders = _eval_gce_meta_placeholders()

    with open(args.input, "r", encoding="utf-8") as in_file, open(
        args.output, "w", encoding="utf-8"
    ) as out_file:
        for line in in_file:
            rendered_line = string.Template(line).substitute(**placeholders)
            out_file.write(rendered_line)
            out_file.write("\n")


if __name__ == "__main__":
    main()
