# Copyright 2021 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

DEPS = [
    "fuchsia/cipd_ensure",
    "recipe_engine/cipd",
    "recipe_engine/file",
    "recipe_engine/path",
]


def RunSteps(api):
    ensure_file = api.cipd.EnsureFile()
    ensure_file.add_package("infra/tool/${platform}", "version:1")
    ensure_file_path = api.path.start_dir / "cipd.ensure"

    api.cipd_ensure.get_packages("get packages", ensure_file_path)
    api.cipd_ensure.get_platforms("get platforms", ensure_file_path)
    api.cipd_ensure.update_packages(
        "update packages",
        ensure_file=ensure_file_path,
        packages=["infra/tool/${platform}"],
        version="version:2",
    )
    api.file.write_text(
        "write ensure file",
        ensure_file_path,
        ensure_file.render(),
    )
    api.cipd_ensure(ensure_file_path, "infra/tool/${platform}")

    roller_metadata_path = api.path.start_dir / "roller_metadata.json"
    api.cipd_ensure.get_roller_metadata(roller_metadata_path)


def GenTests(api):
    yield (
        api.test("basic")
        + api.cipd_ensure.get_packages(
            "get packages",
            {"infra/tool/${platform}": "version:1"},
        )
        + api.cipd_ensure.get_platforms(
            "get platforms",
            ["linux-amd64", "linux-arm64", "mac-amd64"],
        )
        + api.cipd_ensure.update_packages(
            "update packages",
            ["infra/tool/${platform}"],
        )
    )

    yield (
        api.test("no_platforms")
        + api.cipd_ensure.get_platforms(
            "get platforms",
            [],
        )
    )
