# Copyright 2021 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from recipe_engine.recipe_api import Property

DEPS = [
    "fuchsia/buildbucket_util",
    "fuchsia/cipd_util",
    "recipe_engine/cipd",
    "recipe_engine/path",
    "recipe_engine/platform",
    "recipe_engine/properties",
]
PROPERTIES = {
    "fail_if_exists": Property(
        kind=bool,
        help="Whether to fail on existing packages.",
        default=False,
    ),
}


def RunSteps(api, fail_if_exists=False):
    assert api.cipd_util.platform_name == "linux-amd64"

    source_dir = api.path.start_dir
    upload_paths = [
        source_dir,
        source_dir / "my_file",
    ]
    api.cipd_util.upload_package(
        "fuchsia/foo/${platform}",
        source_dir,
        pkg_paths=upload_paths,
        search_tag={"git_revision": "abc1234"},
        repository="https://fuchsia.googlesource.com/tools",
        metadata=[("version", "abc1234"), api.cipd.Metadata("extra_tag", "value")],
        fail_if_exists=fail_if_exists,
    )
    api.cipd_util.hardlink_tree(source_dir)


def GenTests(api):
    pkg = "fuchsia/foo/${platform}"
    revision = "abc1234"

    yield (
        api.buildbucket_util.test("basic")
        + api.platform.name("linux")
        + api.platform.arch("intel")
        + api.platform.bits(64)
    )

    yield api.buildbucket_util.test("tryjob", tryjob=True)

    yield (
        api.buildbucket_util.test("existing_package")
        + api.step_data(
            f"cipd.cipd search {pkg} git_revision:{revision}",
            api.cipd.example_search(pkg),
        )
    )

    yield (
        api.buildbucket_util.test(
            "existing_package_with_fail_if_exists", status="FAILURE"
        )
        + api.step_data(
            f"cipd.cipd search {pkg} git_revision:{revision}",
            api.cipd.example_search(pkg),
        )
        + api.properties(
            fail_if_exists=True,
        )
    )
