# Copyright 2019 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from recipe_engine import recipe_test_api

DEFAULT_COMMIT_QUEUE_CFGS = {
    "default": """
    submit_options: {
      max_burst: 4
      burst_delay: {
        seconds: 480
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "cobalt"
          ref_regexp: "refs/heads/.+"
        }
      }

      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tryjob: {
          builders: {
            name: "fuchsia/try/cobalt-x64-linux"
          }
        }
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "docs"
          ref_regexp: "refs/heads/.+"
        }
      }

      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tryjob: {
          builders: {
            name: "fuchsia/try/doc-checker"
            experiment_percentage: 100
          }
          builders: {
            name: "fuchsia/try/secret-tryjob"
            result_visibility: COMMENT_LEVEL_RESTRICTED
          }
        }
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "fuchsia"
          ref_regexp: "refs/heads/.+"
        }
      }
      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tree_status: {
          url: "https://fuchsia-stem-status.appspot.com"
        }

        tryjob: {
          builders: {
            name: "fuchsia/try/core.arm64-debug"
          }
          builders: {
            name: "fuchsia/try/core.x64-debug"
          }
        }
      }
    }
    """,
    "recipes-only": """
    submit_options: {
      max_burst: 4
      burst_delay: {
        seconds: 480
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "cobalt"
          ref_regexp: "refs/heads/.+"
        }
      }

      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tryjob: {
          builders: {
            name: "fuchsia/try/recipes"
          }
        }
      }
    }
    """,
    "only-fuchsia-debug": """
    submit_options: {
      max_burst: 4
      burst_delay: {
        seconds: 480
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "fuchsia"
          ref_regexp: "refs/heads/.+"
        }
      }
      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tree_status: {
          url: "https://fuchsia-stem-status.appspot.com"
        }

        tryjob: {
          builders: {
            name: "fuchsia/try/core.arm64-debug"
          }
          builders: {
            name: "fuchsia/try/core.x64-debug"
          }
        }
      }
    }
    """,
    "includable_only": """
    submit_options: {
      max_burst: 4
      burst_delay: {
        seconds: 480
      }
    }

    config_groups: {
      gerrit: {
        url: "https:xx//fuchsia-review.googlesource.com"
        projects: {
          name: "fuchsia"
          ref_regexp: "refs/heads/.+"
        }
      }
      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tree_status: {
          url: "https://fuchsia-stem-status.appspot.com"
        }

        tryjob: {
          builders: {
            name: "fuchsia/try/core.arm64-debug"
            includable_only: true
          }
        }
      }
    }
    """,
    "mode_allowlist": """
    config_groups: {
      verifiers: {
        tryjob: {
          builders: {
            name: "fuchsia/tricium/tricium"
            mode_allowlist: "ANALYZER_RUN"
          }
        }
      }
    }
    """,
    "location_filters": """
    config_groups: {
      verifiers: {
        tryjob: {
          builders: {
            name: "fuchsia/foo/foo"
            location_filters {
              path_regexp: "only-run-on-this-path"
            }
          }
          builders: {
            name: "fuchsia/foo/bar"
            location_filters {
              path_regexp: "don't-run-on-this-path"
              exclude: true
            }
          }
        }
      }
    }
    """,
    "empty": """
    submit_options: {
      max_burst: 4
      burst_delay: {
        seconds: 480
      }
    }

    config_groups: {
      gerrit: {
        url: "https://fuchsia-review.googlesource.com"
        projects: {
          name: "fuchsia"
          ref_regexp: "refs/heads/.+"
        }
      }
      verifiers: {
        gerrit_cq_ability: {
          committer_list: "project-fuchsia-committers"
          dry_run_access_list: "project-fuchsia-tryjob-access"
        }
        tree_status: {
          url: "https://fuchsia-stem-status.appspot.com"
        }
      }
    }
    """,
}


class CommitQueueTestApi(recipe_test_api.RecipeTestApi):
    def test_data(self, project, data="default", config_name="commit-queue.cfg"):
        if data in DEFAULT_COMMIT_QUEUE_CFGS:
            data = DEFAULT_COMMIT_QUEUE_CFGS[data]

        return self.m.luci_config.mock_config(project, config_name, data)
