# Copyright 2018 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

DEPS = [
    "fuchsia/docker",
    "recipe_engine/context",
    "recipe_engine/path",
]


def RunSteps(api):
    api.docker.run(
        "gcr.io/fuchsia-container-registry/testimage",
        cmd_args=["test", "cmd"],
        dir_mapping=[("/foo", "/bar")],
        cwd="/external",
        env={"var1": "1", "var2": "2"},
    )
    api.docker("push", "gcr.io/fuchsia-container-registry/image:2018-11-16-01-25")
    with api.docker.create("gcr.io/fuchsia-container-registry/testimage") as temp_copy:
        api.docker.start(temp_copy, attach=True)
        api.docker.exec(
            temp_copy, ["test", "cmd"], cwd="/external", env={"var1": "1", "var2": "2"}
        )
    with api.docker.create(
        "gcr.io/goma-fuchsia/gomatools", name="temp_copy"
    ) as temp_copy:
        api.docker.copy(temp_copy, ["/opt/goma/bin/setup_cmd"], api.path.cleanup_dir)
    with api.docker.create("gcr.io/goma-fuchsia/gomatools") as temp_copy:
        api.docker.copy(temp_copy, ["/opt/goma/bin/auth_server"], "")
    with api.context(cwd=api.path.cleanup_dir):
        api.docker.build(
            dockerfile="Dockerfile",
            cache_from="gcr.io/goma-fuchsia/gomatools",
            tags=["gcr.io/goma-fuchsia/gomatools", "gcr.io/goma-fuchsia/gomatools:r1"],
            build_args=["TOOLCHAIN=clang"],
        )
    api.docker.cleanup()


def GenTests(api):
    yield api.test("example")
