# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from google.protobuf import json_format
from google.protobuf import struct_pb2

from recipe_engine.recipe_api import Property

DEPS = [
    "fuchsia/fxt",
    "recipe_engine/properties",
]

PROPERTIES = {
    "sdk_mode": Property(default=False),
    "piper_presubmit": Property(default=False),
}


def RunSteps(api, sdk_mode, piper_presubmit):
    api.fxt.orchestrate_fxt_tests(
        "foo-bucket",
        "123456",
        options=api.fxt.Options(
            use_staging_host=True,
            tap_projects=["tap-project1", "tap-project2"],
            guitar_config=json_format.ParseDict(
                {"projectfoo": "bar"}, struct_pb2.Struct()
            ),
            sdk_mode=sdk_mode,
            piper_presubmit=piper_presubmit,
        ),
        guitar_test_filter_exprs=["deps(//baz)"],
    )


def GenTests(api):
    yield api.test("successful_tests") + api.fxt.orchestrate_fxt_tests()
    yield (
        api.test("failed_tests_sdk_mode", status="FAILURE")
        + api.properties(sdk_mode=True)
        + api.fxt.orchestrate_fxt_tests(success=False)
    )
    yield (
        api.test("piper_presubmit_success")
        + api.properties(sdk_mode=True, piper_presubmit=True)
        + api.fxt.orchestrate_fxt_tests(piper_presubmit=True)
    )
    yield (
        api.test("piper_presubmit_failure", status="FAILURE")
        + api.properties(sdk_mode=True, piper_presubmit=True)
        + api.fxt.orchestrate_fxt_tests(piper_presubmit=True, success=False)
    )
