# Copyright 2022 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from recipe_engine.recipe_api import Property

DEPS = [
    "fuchsia/buildbucket_util",
    "fuchsia/git_checkout",
    "recipe_engine/assertions",
    "recipe_engine/path",
    "recipe_engine/properties",
]

REMOTE = "https://foo.googlesource.com/foo"

PROPERTIES = {
    "ignore_build_input": Property(default=False),
}


def RunSteps(api, ignore_build_input):
    api.git_checkout(
        REMOTE,
        ignore_build_input=ignore_build_input,
        rebase_merges=True,
        recursive=True,
        submodules=True,
        submodule_force=True,
    )

    # Checkouts should not be allowed to be rooted in start_dir.
    with api.assertions.assertRaises(ValueError):
        api.git_checkout(REMOTE, path=api.path.start_dir)


def GenTests(api):
    yield api.buildbucket_util.test("ci", git_repo=REMOTE)
    yield api.buildbucket_util.test("try", git_repo=REMOTE, tryjob=True)
    yield api.test("no_build_input")
    yield api.test("ignore_build_input") + api.properties(ignore_build_input=True)
