# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

DEPS = [
    "fuchsia/buildbucket_util",
    "fuchsia/kythe",
    "recipe_engine/buildbucket",
    "recipe_engine/file",
    "recipe_engine/path",
]


def RunSteps(api):
    # api.kythe.kythe_dir needs to be both set and not set for coverage to be
    # complete, and this was easy.
    if api.buildbucket_util.is_tryjob:
        api.kythe.kythe_dir = api.path.start_dir / "kythe"
        api.kythe.kythe_libs_dir = api.path.start_dir / "kythe-libs"

    api.kythe.extract_and_upload(
        checkout_dir=api.path.start_dir / "checkout",
        build_dir=api.path.start_dir / "build",
        corpus="corpus",
        gcs_bucket="bucket",
        gcs_filename="filename",
        vnames_path="path/to/vnames.json",
    )


def GenTests(api):
    yield api.test("try") + api.buildbucket.try_build() + api.kythe.valid()

    yield (
        api.test("kzips")
        + api.step_data("glob kzips", api.file.glob_paths(["foo.kzip", "bar.kzip"]))
        + api.kythe.valid()
    )

    yield api.test("validation_no_output", status="FAILURE")

    yield api.test("validation_failure", status="FAILURE") + api.kythe.invalid()
