# Copyright 2023 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from contextlib import contextmanager

from recipe_engine import recipe_api


class LinuxSDKApi(recipe_api.RecipeApi):
    """API for the Linux SDK."""

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._sysroot = None

    @property
    def sysroot(self):
        assert self._sysroot
        return self._sysroot

    @contextmanager
    def __call__(self):
        """Sets up the Linux SDK environment.

        This call is a no-op on non-Linux platforms.
        """
        if not self.m.platform.is_linux:
            yield
            return

        try:
            self._sysroot = self.m.cipd_ensure(
                self.resource("cipd.ensure"),
                "fuchsia/third_party/sysroot/linux",
                executable_path="",
            )
            yield
        finally:
            self._sysroot = None
