# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from recipe_engine import recipe_test_api

from PB.go.chromium.org.luci.buildbucket.proto import (
    builds_service as builds_service_pb2,
)

from PB.recipe_modules.fuchsia.presubmit_util.options import Options


class PresubmitUtilTestApi(recipe_test_api.RecipeTestApi):
    Options = Options

    def create_cl(self, nesting=None, test_data=None):
        step_prefix = nesting + "." if nesting else ""
        if not test_data:
            test_data = {
                "number": 123456,
                "current_revision": "foo",
                "revisions": {"foo": {"number": 1}},
            }
        return self.step_data(f"{step_prefix}create CL", self.m.json.output(test_data))

    def wait_for_cq(self, success=True):
        return self.step_data("wait for CQ", self.m.json.output(success))

    def trigger_tryjobs(self, tryjob_msgs, nesting=None):
        step_prefix = nesting + "." if nesting else ""
        responses = [{"schedule_build": m} for m in tryjob_msgs]
        return self.m.buildbucket.simulated_schedule_output(
            batch_response=builds_service_pb2.BatchResponse(responses=responses),
            step_name=f"{step_prefix}trigger tryjobs.schedule",
        )

    def collect_tryjobs(
        self, nesting=None, builders=None, tryjob_msgs=None, status="SUCCESS"
    ):
        step_prefix = nesting + "." if nesting else ""
        if builders:
            tryjob_msgs = []
            for idx, builder in enumerate(builders):
                project, bucket, builder_name = builder.split("/")
                msg = self.m.buildbucket.try_build_message(
                    builder=builder_name,
                    bucket=bucket,
                    project=project,
                    build_id=(idx + 1) * 1234567890,
                    status=status,
                )
                tryjob_msgs.append(msg)
            search_results = (
                self.m.buildbucket.simulated_multi_predicates_search_results(
                    tryjob_msgs,
                    step_name=f"{step_prefix}resolve triggered build IDs.search",
                )
            )
        collect_data = self.m.buildbucket.simulated_collect_output(
            tryjob_msgs,
            step_name=f"{step_prefix}collect tryjobs.collect",
        )
        if builders:
            return search_results + collect_data
        return collect_data
