# Copyright 2021 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from PB.recipe_modules.fuchsia.rbe.properties import InputProperties
from PB.go.fuchsia.dev.foundry_x.re_client.api.proxy import log as log_pb2
from PB.go.api.command import command as command_pb2

DEPS = [
    "fuchsia/rbe",
    "recipe_engine/buildbucket",
    "recipe_engine/file",
    "recipe_engine/path",
    "recipe_engine/properties",
    "recipe_engine/step",
]


def RunSteps(api):
    with api.rbe(reclient_path=api.path.cleanup_dir / "rbe"):
        # build something using rbe.
        api.step("build", ["echo", "Mission Complete!"])
        api.step(
            "cmake",
            [
                f"cmake -DCMAKE_CXX_COMPILER_LAUNCHER={api.rbe.cxx_compiler_wrapper()}",
                "C++ compiler wrapped!",
            ],
        )

    for p in (
        api.rbe.AbsolutePathPolicy.RELATIVIZE,
        api.rbe.AbsolutePathPolicy.REJECT,
        api.rbe.AbsolutePathPolicy.ALLOW,
    ):
        with api.rbe(absolute_path_policy=p):
            api.step(
                "cmake",
                [
                    f"cmake -DCMAKE_CXX_COMPILER_LAUNCHER={api.rbe.cxx_compiler_wrapper()}",
                    "C++ compiler wrapped!",
                ],
            )

    with api.rbe(config_path=api.path.cleanup_dir / "configs"):
        # build something using rbe.
        api.step("build", ["echo", "Misison Accomplished!"])


def GenTests(api):
    def rbe_properties(**kwargs):
        kwargs.setdefault("instance", "projects/fuchsia-infra/instance/default")
        kwargs.setdefault(
            "platform",
            "container-image=docker://gcr.io/cloud-marketplace/google/debian11@sha256:69e2789c9f3d28c6a0f13b25062c240ee7772be1f5e6d41bb4680b63eae6b304",
        )
        props = api.properties(
            **{"$fuchsia/rbe": InputProperties(**kwargs)}
        ) + api.buildbucket.try_build(project="test", builder="test")
        return props

    yield (
        api.test("basic")
        + api.step_data(
            "teardown remote execution.read reproxy_log.pb",
            api.file.read_proto(
                log_pb2.LogDump(
                    records=[
                        log_pb2.LogRecord(
                            command=command_pb2.Command(
                                exec_root="/path/to/root",
                                platform={"a": "b", "c": "d"},
                                input=command_pb2.InputSpec(
                                    environment_variables={
                                        "var1": "val1",
                                        "var2": "val2",
                                    },
                                ),
                            ),
                            local_metadata=log_pb2.LocalMetadata(
                                executed_locally=False,
                                environment={"e": "f", "g": "h"},
                                labels={"i": "j"},
                                rerun_metadata=[
                                    log_pb2.RerunMetadata(
                                        output_file_digests={
                                            "file1": "digest1",
                                            "file2": "digest2",
                                        },
                                        output_directory_digests={
                                            "dir1": "digest1",
                                            "dir2": "digest2",
                                        },
                                    )
                                ],
                            ),
                            remote_metadata=log_pb2.RemoteMetadata(
                                cache_hit=True,
                                num_input_files=42,
                                output_file_digests={
                                    "file1": "digest1",
                                    "file2": "digest2",
                                },
                                output_directory_digests={
                                    "dir1": "digest1",
                                    "dir2": "digest2",
                                },
                                rerun_metadata=[
                                    log_pb2.RerunMetadata(
                                        output_file_digests={
                                            "file1": "digest1",
                                            "file2": "digest2",
                                        },
                                        output_directory_digests={
                                            "dir1": "digest1",
                                            "dir2": "digest2",
                                        },
                                    )
                                ],
                            ),
                        ),
                    ],
                ),
            ),
        )
        + rbe_properties()
    )

    yield (
        api.test("start_rbe_failed", status="INFRA_FAILURE")
        + api.step_data("setup remote execution.start reproxy", retcode=1)
    )

    yield (
        api.test("stop_rbe_failed", status="INFRA_FAILURE")
        + api.step_data("teardown remote execution.stop reproxy", retcode=1)
    )

    yield (
        api.test("read_log_proto_failure_does_not_block")
        + api.step_data("teardown remote execution.read reproxy_log.pb", retcode=1)
        + rbe_properties()
    )
