# Copyright 2023 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from PB.go.fuchsia.dev.shac_project.shac.internal.sarif import sarif as sarif_pb2

from RECIPE_MODULES.fuchsia.shac.api import MAX_COMMENTS

DEPS = [
    "fuchsia/buildbucket_util",
    "fuchsia/git",
    "fuchsia/shac",
    "recipe_engine/json",
    "recipe_engine/path",
    "recipe_engine/proto",
]


def RunSteps(api):
    checkout_dir = api.path.mkdtemp("checkout")
    shac_path = checkout_dir / "shac"
    api.shac.check(
        root=checkout_dir,
        shac_path=shac_path,
        revision="abc123",
        runtime_vars={"foo": "bar", "baz": "quux"},
        entrypoint="other_shac.star",
    )


def GenTests(api):
    yield api.buildbucket_util.test("pass")

    yield api.buildbucket_util.test(
        "change_in_different_repo", repo="other_repo", tryjob=True
    )

    yield (
        api.buildbucket_util.test("fail", tryjob=True, status="FAILURE")
        + api.git.get_changed_files(
            "get changed files.git diff-tree",
            ["src/script.py"],
        )
        + api.step_data(
            "get previous robot comments",
            api.json.output(
                {
                    "src/script.py": [
                        {
                            "message": "preexisting comment",
                            "robot_id": "foo",
                            "range": {
                                "start_line": 10,
                                "start_character": 4,
                                "end_line": 11,
                                "end_character": 6,
                            },
                        },
                        {
                            "message": "preexisting file-level comment",
                            "robot_id": "foo",
                            "range": {},
                        },
                    ]
                }
            ),
        )
        + api.step_data(
            "shac check",
            api.proto.output(
                sarif_pb2.Document(
                    runs=[
                        sarif_pb2.Run(
                            tool=sarif_pb2.Tool(
                                driver=sarif_pb2.ToolComponent(name="foo")
                            ),
                            results=[
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(
                                        text="preexisting comment"
                                    ),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri="src/script.py",
                                                ),
                                                region=sarif_pb2.Region(
                                                    start_line=10,
                                                    start_column=5,
                                                    end_line=11,
                                                    end_column=7,
                                                ),
                                            )
                                        )
                                    ],
                                ),
                                sarif_pb2.Result(
                                    level="warning",
                                    message=sarif_pb2.Message(
                                        text="finding in an unchanged file"
                                    ),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri="src/unchanged.py",
                                                ),
                                            )
                                        )
                                    ],
                                ),
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(
                                        text="preexisting file-level comment"
                                    ),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri="src/script.py",
                                                ),
                                            )
                                        )
                                    ],
                                ),
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(text="found an issue"),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri="src/script.py",
                                                ),
                                                region=sarif_pb2.Region(
                                                    start_line=4,
                                                    start_column=2,
                                                    end_line=5,
                                                    end_column=1,
                                                ),
                                            )
                                        )
                                    ],
                                    fixes=[
                                        sarif_pb2.Fix(
                                            description=sarif_pb2.Message(
                                                text="here's how to fix it"
                                            ),
                                            artifact_changes=[
                                                sarif_pb2.ArtifactChange(
                                                    artifact_location=sarif_pb2.ArtifactLocation(
                                                        uri="src/script.py",
                                                    ),
                                                    replacements=[
                                                        sarif_pb2.Replacement(
                                                            deleted_region=sarif_pb2.Region(
                                                                start_line=10,
                                                                start_column=4,
                                                            ),
                                                            inserted_content=sarif_pb2.ArtifactContent(
                                                                text="replacement text"
                                                            ),
                                                        ),
                                                        sarif_pb2.Replacement(
                                                            inserted_content=sarif_pb2.ArtifactContent(
                                                                text="replacement for whole file"
                                                            ),
                                                        ),
                                                    ],
                                                )
                                            ],
                                        )
                                    ],
                                ),
                            ],
                        ),
                        sarif_pb2.Run(
                            tool=sarif_pb2.Tool(
                                driver=sarif_pb2.ToolComponent(
                                    name="patchset_level_checker"
                                )
                            ),
                            results=[
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(text="found an issue"),
                                ),
                            ],
                        ),
                        sarif_pb2.Run(
                            tool=sarif_pb2.Tool(
                                driver=sarif_pb2.ToolComponent(
                                    name="commit_message_checker"
                                )
                            ),
                            results=[
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(text="found an issue"),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    # Empty uri indicates the
                                                    # commit message.
                                                    uri="",
                                                ),
                                                region=sarif_pb2.Region(
                                                    start_line=4,
                                                    start_column=2,
                                                    end_line=5,
                                                    end_column=1,
                                                ),
                                            )
                                        )
                                    ],
                                ),
                            ],
                        ),
                        sarif_pb2.Run(
                            tool=sarif_pb2.Tool(
                                driver=sarif_pb2.ToolComponent(
                                    name="check_with_lots_of_errors"
                                )
                            ),
                            results=[
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(
                                        text="oops there's a problem"
                                    ),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri=f"src/foo{i}.py",
                                                ),
                                                region=sarif_pb2.Region(start_line=i),
                                            )
                                        )
                                    ],
                                )
                                for i in range(20)
                            ],
                        ),
                    ],
                )
            ),
            retcode=1,
        )
    )

    yield (
        api.buildbucket_util.test("too_many_comments", tryjob=True, status="FAILURE")
        + api.git.get_changed_files(
            "get changed files.git diff-tree",
            ["src/script.py"],
        )
        + api.step_data(
            "shac check",
            api.proto.output(
                sarif_pb2.Document(
                    runs=[
                        sarif_pb2.Run(
                            tool=sarif_pb2.Tool(
                                driver=sarif_pb2.ToolComponent(
                                    name="check_with_lots_of_errors"
                                )
                            ),
                            results=[
                                sarif_pb2.Result(
                                    level="error",
                                    message=sarif_pb2.Message(
                                        text="oops there's a problem"
                                    ),
                                    locations=[
                                        sarif_pb2.Location(
                                            physical_location=sarif_pb2.PhysicalLocation(
                                                artifact_location=sarif_pb2.ArtifactLocation(
                                                    uri="src/script.py",
                                                ),
                                                region=sarif_pb2.Region(start_line=i),
                                            )
                                        )
                                    ],
                                )
                                for i in range(MAX_COMMENTS + 10)
                            ],
                        ),
                    ],
                )
            ),
            retcode=1,
        )
    )
