# Copyright 2019 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

from recipe_engine.config import List
from recipe_engine.recipe_api import Property

DEPS = [
    "fuchsia/sso",
    "recipe_engine/defer",
    "recipe_engine/properties",
    "recipe_engine/step",
]

PROPERTIES = {
    # Extra hosts are separate from hosts because hosts gets processed during
    # initialize() which can't fail in tests.
    "extra_hosts": Property(kind=List(str), default=()),
}


def RunSteps(api, extra_hosts):
    with api.step.nest("steps"):
        api.sso.initialize()
        api.sso.configure_insteadof("fuchsia")
        api.sso.configure_insteadof("sso://purple")

        # Converted to "https://fuchsia.googlesource.com/fuchsia.git".
        sso_to_https(api, "sso://fuchsia/fuchsia.git")
        sso_to_https(api, "sso://fuchsia.googlesource.com/fuchsia.git")
        sso_to_https(api, "sso://fuchsia.git.corp.google.com/fuchsia.git")
        sso_to_https(api, "https://fuchsia.git.corp.google.com/fuchsia.git")

        # Not an "sso://" or ".git.corp.google.com" URL, unchanged.
        sso_to_https(api, "https://fuchsia/fuchsia")

        with api.defer.context() as defer:
            for host in extra_hosts:
                defer(api.sso.configure_insteadof, host)


def sso_to_https(api, sso):
    with api.step.nest("sso to https") as pres:
        pres.logs["sso"] = sso
        pres.logs["https"] = api.sso.sso_to_https(sso)


def GenTests(api):
    def props(*args, **kwargs):
        extra_hosts = kwargs.pop("extra_hosts", [])
        return api.properties(
            extra_hosts=extra_hosts, **api.sso.properties(*args, **kwargs)
        )

    yield api.test("basic") + props()

    yield (
        api.test("multiple")
        + props(
            hosts=[
                "fuchsia",
                "fuchsia.googlesource.com",
                "fuchsia.git.corp.google.com",
            ],
        )
    )

    yield (
        api.test("bad", status="FAILURE")
        + props(extra_hosts=[".fuchsia", "fuchsia.", "fuch_sia"])
        + props(extra_hosts=[".fuchsia", "fuchsia.", "fuch_sia", "fuch-sia"])
    )
