# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

DEPS = [
    "fuchsia/toolchain",
    "recipe_engine/buildbucket",
    "recipe_engine/cipd",
    "recipe_engine/context",
    "recipe_engine/file",
    "recipe_engine/path",
    "recipe_engine/step",
]


def RunSteps(api):
    with api.step.nest("ensure_packages"):
        with api.context(infra_steps=True):
            pkgs = api.cipd.EnsureFile()
            cipd_dir = api.path.start_dir / "cipd"
            pkgs.add_package("fuchsia/third_party/clang/${platform}", "integration")
            pkgs.add_package("fuchsia/tools/breakpad/${platform}", "latest", "breakpad")

    # Where we'll build our toolchain
    staging_dir = api.path.mkdtemp("clang")
    pkg_dir = staging_dir / "clang"
    runtime_dir = pkg_dir / "lib"

    # Build toolchain here.
    api.file.ensure_directory("create package dirs", runtime_dir)

    runtimes_spec = [
        {
            "target": ["x86_64-unknown-fuchsia", "x86_64-fuchsia"],
            # Other selector keys, like "cflags", "ldflags", or "rustflags", go here.
            "runtime": [
                # The path in "dist" should be relative to runtime.json.
                # The "debug" and "breakpad" keys will be filled in automatically.
                {
                    "soname": "libclang_rt.so",
                    "dist": "clang/lib/x86_64-unknown-fuchsia/libclang_rt.so",
                }
            ],
        },
        {
            "target": ["aarch64-unknown-fuchsia", "aarch64-fuchsia"],
            "runtime": [
                {
                    "soname": "libclang_rt.so",
                    "dist": "clang/lib/aarch64-unknown-fuchsia/libclang_rt.so",
                }
            ],
        },
    ]
    api.toolchain.strip_runtimes(
        "generate runtime.json",
        spec=runtimes_spec,
        path=pkg_dir / "lib",
        build_id_subpath="debug/.build-id",
        readelf=cipd_dir.joinpath("bin", "llvm-readelf"),
        objcopy=cipd_dir.joinpath("bin", "llvm-objcopy"),
        dump_syms=cipd_dir.joinpath("breakpad", "dump_syms", "dump_syms"),
        dist="dist",
    )

    api.toolchain.trigger_build(
        "clang_toolchain",
        gitiles_repository="https://fuchsia.googlesource.com/third_party/llvm-project",
        gitiles_revision="65577e6e78b89123aeea2699fa67ac5a09318207",
        digest="527ffd078a64dfa3f93909ba9f8dd8d71617897a/123",
        builders=["fuchsia/clang_toolchain-arm64", "other_project/clang_toolchain-x64"],
    )


def GenTests(api):
    yield api.test("full") + api.buildbucket.ci_build()
