#!/usr/bin/env vpython3

# Copyright 2021 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

# [VPYTHON:BEGIN]
# python_version: "3.8"
# wheel: <
#   name: "infra/python/wheels/idna-py2_py3"
#   version: "version:2.10"
# >
# wheel: <
#   name: "infra/python/wheels/urllib3-py2_py3"
#   version: "version:1.26.4"
# >
# wheel: <
#   name: "infra/python/wheels/certifi-py2_py3"
#   version: "version:2020.12.5"
# >
# wheel: <
#   name: "infra/python/wheels/chardet-py2_py3"
#   version: "version:4.0.0"
# >
# wheel: <
#   name: "infra/python/wheels/requests-py2_py3"
#   version: "version:2.25.1"
# >
# [VPYTHON:END]

"""Read JSON output from llvm-lit and upload the data to resultDB.

Usage:
  rdb [rdb flags] -- resultdb.py --json=JSON_FILE
"""

import json
import argparse
import os
import sys
import requests


def read_jsons(json_files):
    test_results = []
    for json_file in json_files:
        with open(json_file) as f:
            data = json.load(f)
        test_results.extend(data["tests"])
    return test_results


def upload_results(test_results, url, auth_token):
    res = requests.post(
        url,
        headers={
            "Content-Type": "application/json",
            "Accept": "application/json",
            "Authorization": "ResultSink %s" % auth_token,
        },
        data=json.dumps({"testResults": test_results}),
    )
    res.raise_for_status()


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--json", action="append", help="json output from llvm-lit")
    args = parser.parse_args()
    if not args.json:
        print("Please specify the lit json file(s).")
        return 1
    sink = None
    if "LUCI_CONTEXT" in os.environ:
        with open(os.environ["LUCI_CONTEXT"]) as f:
            sink = json.load(f)["result_sink"]
    if sink is None:
        print("result_sink not defined")
        return 1
    test_results = read_jsons(args.json)
    if not test_results:
        print("Empty test results: skipping")
        return 0
    url = str.format(
        "http://{}/prpc/luci.resultsink.v1.Sink/{}",
        sink["address"],
        "ReportTestResults",
    )
    upload_results(test_results, url, sink["auth_token"])


if __name__ == "__main__":
    sys.exit(main())
