# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Recipe to build the Linux host sysroot and upload it to CIPD."""

from PB.recipes.fuchsia.contrib.linux_sysroot import InputProperties

DEPS = [
    "fuchsia/build",
    "fuchsia/buildbucket_util",
    "fuchsia/checkout",
    "fuchsia/cipd_util",
    "recipe_engine/buildbucket",
    "recipe_engine/path",
    "recipe_engine/properties",
    "recipe_engine/step",
]

PROPERTIES = InputProperties


def RunSteps(api, props):
    bb_build = api.buildbucket.build

    checkout = api.checkout.fuchsia_with_options(
        manifest=props.manifest,
        remote=props.remote,
    )

    build_results = api.build.with_options(
        checkout=checkout, fint_params_path=props.fint_params_path
    )

    lockfile = checkout.root_dir.joinpath(
        "tools", "debroot", "cmd", f"{props.release or 'packages'}.lock"
    )
    sysroot_dir = api.path.mkdtemp("sysroot")
    debroot = build_results.tool("debroot")
    api.step(
        "generate sysroot",
        [debroot, "install", "-out", sysroot_dir, lockfile],
    )

    commit = bb_build.input.gitiles_commit
    repository = f"https://{commit.host}/{commit.project}"
    api.cipd_util.upload_package(
        f"fuchsia/third_party/sysroot/{props.release or 'linux'}",
        sysroot_dir,
        search_tag={"git_revision": commit.id},
        repository=repository,
    )


def GenTests(api):
    yield (
        api.buildbucket_util.test("basic")
        + api.properties(
            manifest="minimal",
            remote="https://fuchsia.googlesource.com/fuchsia",
            fint_params_path="specs/linux-sysroot.textproto",
        )
    )
