# Copyright 2020 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

import argparse
import os
import shutil


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--source_dir")
    parser.add_argument("--dest_dir")
    opts = parser.parse_args()

    # Validate args
    if not opts.source_dir or not opts.dest_dir:
        parser.exit("must provide both --source_dir and --dest_dir")
    if not os.path.exists(opts.source_dir):
        parser.exit("%s does not exist" % opts.source_dir)

    if not os.path.exists(opts.dest_dir):
        os.makedirs(opts.dest_dir)

    for dirpath, _, files in os.walk(opts.source_dir):
        for f in files:
            source = os.path.join(dirpath, f)
            relpath = os.path.relpath(source, opts.source_dir)
            dest = os.path.join(opts.dest_dir, relpath)
            if os.path.exists(dest):
                continue

            dest_dirpath = os.path.dirname(dest)
            if not os.path.exists(dest_dirpath):
                os.makedirs(dest_dirpath)
            shutil.copy(source, dest)


if __name__ == "__main__":
    main()
