#!/bin/bash -ex
# Copyright 2023 The Fuchsia Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

repo="$1"
ref="$2"

if [ "llvm-project" != $(basename $(pwd)) ]; then
    echo "FATAL: Must be invoked from llvm-project directory"
    exit 1
fi

if [ "$(git remote | grep -F llvm | wc -l)" -ne "0" ]; then
    git remote remove llvm
fi
git remote add llvm "$repo"
git fetch llvm "$ref"
git checkout FETCH_HEAD

cd ../../

# Unmerged PRs we care about, via the `llvm-main` label on GitHub. The PR author
# should be able to apply the label themselves, or anyone with the right
# permissions can do so with `@rustbot label +llvm-main` in a comment.
UNMERGED_PRS="$(curl --silent -H "Accept: application/vnd.github.v3+json" 'https://api.github.com/search/issues?q=is:open+label:llvm-main' | \
  python3 -c 'import json,sys; data = json.load(sys.stdin) ; print(" ".join(str(pr["number"]) for pr in data["items"]))')"

for pr in $UNMERGED_PRS; do
  if [ ! -z "$(curl --silent -H "Accept: application/vnd.github.v3+json" https://api.github.com/repos/rust-lang/rust/pulls/${pr}/merge)" ] ; then
    # unmerged PR we care about, so apply it as a patch
    echo "--- Apply unmerged PR #${pr}..."
    curl -L "https://github.com/rust-lang/rust/pull/${pr}.patch" | git am
  fi
done
